# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator (autorest: 3.10.3, generator: @autorest/python@5.16.0)
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

try:
    from ._models_py3 import Accreditation
    from ._models_py3 import Annotation
    from ._models_py3 import AnnotationBase
    from ._models_py3 import AnnotationBatchUpdate
    from ._models_py3 import AnnotationCreate
    from ._models_py3 import AnnotationUpdate
    from ._models_py3 import AnnotationWithValidationResults
    from ._models_py3 import AnotationDelete
    from ._models_py3 import ApiUserCreate
    from ._models_py3 import ApiUserUpdate
    from ._models_py3 import ApiUserWithKey
    from ._models_py3 import ApiUserWithKeyOrganizationsItem
    from ._models_py3 import ApiUserWithoutKey
    from ._models_py3 import ApiUserWithoutKeyOrganizationsItem
    from ._models_py3 import BaseExtractor
    from ._models_py3 import BatchAddTagRequest
    from ._models_py3 import BatchDeleteAnnotationsResponse
    from ._models_py3 import BatchDeleteValidationResultsRequest
    from ._models_py3 import BatchRemoveTagRequest
    from ._models_py3 import ChangedValidationResults
    from ._models_py3 import Collection
    from ._models_py3 import CollectionCreate
    from ._models_py3 import CollectionField
    from ._models_py3 import CollectionUpdate
    from ._models_py3 import CollectionWorkspace
    from ._models_py3 import (
        Components159Ji55SchemasResumesearchdetailPropertiesLanguagesPropertiesValueItemsAllof1,
    )
    from ._models_py3 import (
        Components1Kwk9B6SchemasThemeconfigPropertiesPalettePropertiesBackgroundOneof1,
    )
    from ._models_py3 import (
        Components1TlnsonSchemasJobdescriptionsearchdetailPropertiesLocationPropertiesValueAllof1,
    )
    from ._models_py3 import (
        Components1TryetgSchemasResumedataPropertiesWorkexperienceItemsPropertiesOccupationPropertiesClassification,
    )
    from ._models_py3 import (
        ComponentsH65QjbSchemasResumesearchdetailPropertiesSkillsPropertiesValueItemsAllof1,
    )
    from ._models_py3 import (
        ComponentsN9ShogSchemasResumesearchdetailPropertiesLocationPropertiesValueAllof1,
    )
    from ._models_py3 import (
        ComponentsNqbw24SchemasCustomdatasearchscorecomponentAdditionalproperties,
    )
    from ._models_py3 import (
        ComponentsSxu0N3SchemasResumesearchdetailPropertiesEducationPropertiesValueItemsAllof1,
    )
    from ._models_py3 import CurrencyCodeAnnotation
    from ._models_py3 import CustomFieldConfig
    from ._models_py3 import DataField
    from ._models_py3 import DataFieldCreate
    from ._models_py3 import DataFieldCreateDataPoint
    from ._models_py3 import DataFieldCreateField
    from ._models_py3 import DataFieldDataPoint
    from ._models_py3 import DataFieldField
    from ._models_py3 import DataPoint
    from ._models_py3 import DataPointChoice
    from ._models_py3 import DataPointChoiceCreate
    from ._models_py3 import DataPointChoiceForReplace
    from ._models_py3 import DataPointChoiceReplaceRequest
    from ._models_py3 import DataPointChoiceReplaceResponse
    from ._models_py3 import DataPointChoiceReplaceResponseChoicesItem
    from ._models_py3 import DataPointChoiceUpdate
    from ._models_py3 import DataPointCreate
    from ._models_py3 import DataPointUpdate
    from ._models_py3 import DateAnnotation
    from ._models_py3 import DateAnnotationUpdate
    from ._models_py3 import DateRangeAnnotation
    from ._models_py3 import DateRangeAnnotationParsed
    from ._models_py3 import DateRangeValue
    from ._models_py3 import Document
    from ._models_py3 import DocumentCreate
    from ._models_py3 import DocumentEditRequest
    from ._models_py3 import DocumentError
    from ._models_py3 import DocumentMeta
    from ._models_py3 import DocumentMetaChildDocumentsItem
    from ._models_py3 import DocumentMetaCollection
    from ._models_py3 import DocumentMetaCollectionExtractor
    from ._models_py3 import DocumentMetaParentDocument
    from ._models_py3 import DocumentMetaWorkspace
    from ._models_py3 import DocumentSplit
    from ._models_py3 import DocumentSplitPage
    from ._models_py3 import DocumentSplitter
    from ._models_py3 import DocumentType
    from ._models_py3 import DocumentTypeCreate
    from ._models_py3 import DocumentTypeUpdate
    from ._models_py3 import DocumentUpdate
    from ._models_py3 import DocumentWarning
    from ._models_py3 import Education
    from ._models_py3 import EducationDates
    from ._models_py3 import EducationGrade
    from ._models_py3 import EducationSearchScoreComponent
    from ._models_py3 import ExpectedRemunerationAnnotation
    from ._models_py3 import ExpectedRemunerationAnnotationParsed
    from ._models_py3 import ExpectedRemunerationAnnotationUpdate
    from ._models_py3 import ExpectedRemunerationAnnotationUpdateParsed
    from ._models_py3 import ExperienceSearchScoreComponent
    from ._models_py3 import Extractor
    from ._models_py3 import ExtractorBaseExtractor
    from ._models_py3 import ExtractorConfig
    from ._models_py3 import ExtractorCreate
    from ._models_py3 import ExtractorUpdate
    from ._models_py3 import Field
    from ._models_py3 import FieldCategory
    from ._models_py3 import FieldDeprecated
    from ._models_py3 import FieldGroup
    from ._models_py3 import FieldsLayout
    from ._models_py3 import FloatAnnotation
    from ._models_py3 import Get200ApplicationJsonPropertiesItemsItem
    from ._models_py3 import Index
    from ._models_py3 import IndexCreate
    from ._models_py3 import IndexUpdate
    from ._models_py3 import IndexUser
    from ._models_py3 import Invitation
    from ._models_py3 import InvitationCreate
    from ._models_py3 import InvitationRespondedBy
    from ._models_py3 import InvitationResponse
    from ._models_py3 import InvitationUpdate
    from ._models_py3 import Invoice
    from ._models_py3 import InvoiceData
    from ._models_py3 import JobDescription
    from ._models_py3 import JobDescriptionData
    from ._models_py3 import JobDescriptionDataUpdate
    from ._models_py3 import JobDescriptionSearch
    from ._models_py3 import JobDescriptionSearchConfig
    from ._models_py3 import JobDescriptionSearchConfigSearchToolTheme
    from ._models_py3 import JobDescriptionSearchDetail
    from ._models_py3 import JobDescriptionSearchDetailEducation
    from ._models_py3 import JobDescriptionSearchDetailEducationMissing
    from ._models_py3 import JobDescriptionSearchDetailEducationValue
    from ._models_py3 import JobDescriptionSearchDetailExperience
    from ._models_py3 import JobDescriptionSearchDetailJobTitle
    from ._models_py3 import JobDescriptionSearchDetailJobTitleValue
    from ._models_py3 import JobDescriptionSearchDetailLanguages
    from ._models_py3 import JobDescriptionSearchDetailLanguagesValueItem
    from ._models_py3 import JobDescriptionSearchDetailLocation
    from ._models_py3 import JobDescriptionSearchDetailLocationValue
    from ._models_py3 import JobDescriptionSearchDetailManagementLevel
    from ._models_py3 import JobDescriptionSearchDetailOccupationGroup
    from ._models_py3 import JobDescriptionSearchDetailOccupationGroupValue
    from ._models_py3 import JobDescriptionSearchDetailSearchExpression
    from ._models_py3 import JobDescriptionSearchDetailSkills
    from ._models_py3 import JobDescriptionSearchDetailSkillsValueItem
    from ._models_py3 import JobDescriptionSearchEmbed
    from ._models_py3 import JobDescriptionSearchParameters
    from ._models_py3 import JobDescriptionSearchResult
    from ._models_py3 import JobTitleAnnotation
    from ._models_py3 import JobTitleAnnotationParsed
    from ._models_py3 import JobTitleAnnotationParsedClassification
    from ._models_py3 import JobTitleAnnotationUpdate
    from ._models_py3 import JobTitleParsed
    from ._models_py3 import JobTitleParsedClassification
    from ._models_py3 import JobTitleParsedParsed
    from ._models_py3 import JobTitleSearchScoreComponent
    from ._models_py3 import LanguageAnnotation
    from ._models_py3 import LanguageAnnotationUpdate
    from ._models_py3 import LanguagesSearchScoreComponent
    from ._models_py3 import Location
    from ._models_py3 import LocationAnnotation
    from ._models_py3 import LocationAnnotationUpdate
    from ._models_py3 import LocationAnnotationUpdateParsed
    from ._models_py3 import LocationSearchScoreComponent
    from ._models_py3 import ManagementLevelSearchScoreComponent
    from ._models_py3 import Mapping
    from ._models_py3 import MappingCreate
    from ._models_py3 import MappingDataSource
    from ._models_py3 import MappingDataSourceCreate
    from ._models_py3 import MappingUpdate
    from ._models_py3 import Meta
    from ._models_py3 import MetaChildDocumentsItem
    from ._models_py3 import MetaParentDocument
    from ._models_py3 import OccupationGroup
    from ._models_py3 import OccupationGroupSearchResult
    from ._models_py3 import OccupationGroupSearchScoreComponent
    from ._models_py3 import Organization
    from ._models_py3 import OrganizationCreate
    from ._models_py3 import OrganizationMembership
    from ._models_py3 import OrganizationMembershipUpdate
    from ._models_py3 import OrganizationUpdate
    from ._models_py3 import OrganizationValidationToolConfig
    from ._models_py3 import PageMeta
    from ._models_py3 import PaginatedResponse
    from ._models_py3 import PaletteColorOptions
    from ._models_py3 import (
        Paths11PzrpaV3ApiUsersGetResponses200ContentApplicationJsonSchemaAllof1,
    )
    from ._models_py3 import (
        Paths11QdcofV3MappingDataSourcesGetResponses200ContentApplicationJsonSchema,
    )
    from ._models_py3 import Paths18Wh2VcV3InvitationsGetResponses200ContentApplicationJsonSchema
    from ._models_py3 import (
        Paths1Czpnk1V3ResumeSearchEmbedPostRequestbodyContentApplicationJsonSchema,
    )
    from ._models_py3 import Paths1D5Zg6MV3AnnotationsGetResponses200ContentApplicationJsonSchema
    from ._models_py3 import (
        Paths1Dgz0V9V3AnnotationsGetResponses200ContentApplicationJsonSchemaAllof1,
    )
    from ._models_py3 import Paths1Dpvb2PV3MappingsGetResponses200ContentApplicationJsonSchema
    from ._models_py3 import (
        Paths1O6IvdaV3MappingDataSourcesIdentifierValuesGetResponses200ContentApplicationJsonSchemaAllof1,
    )
    from ._models_py3 import (
        Paths1Qojy9V3ResthookSubscriptionsGetResponses200ContentApplicationJsonSchemaAllof1,
    )
    from ._models_py3 import (
        Paths1Qr7BnyV3MappingDataSourcesIdentifierValuesGetResponses200ContentApplicationJsonSchema,
    )
    from ._models_py3 import (
        Paths1UmoszuV3MappingDataSourcesGetResponses200ContentApplicationJsonSchemaAllof1,
    )
    from ._models_py3 import Paths26Civ0V3ApiUsersGetResponses200ContentApplicationJsonSchema
    from ._models_py3 import (
        Paths2Ld2HiV3WorkspaceMembershipsGetResponses200ContentApplicationJsonSchemaAllof1,
    )
    from ._models_py3 import (
        Paths4K6IzqV3DataPointChoicesGetResponses200ContentApplicationJsonSchemaAllof1,
    )
    from ._models_py3 import Paths4T5Cm5V3IndexGetResponses200ContentApplicationJsonSchemaAllof1
    from ._models_py3 import (
        Paths93Fa0ZV3OrganizationMembershipsGetResponses200ContentApplicationJsonSchemaAllof1,
    )
    from ._models_py3 import (
        PathsCl024WV3IndexNameDocumentsPostRequestbodyContentApplicationJsonSchema,
    )
    from ._models_py3 import PathsDvrcp3V3IndexGetResponses200ContentApplicationJsonSchema
    from ._models_py3 import (
        PathsFte27NV3IndexNameDocumentsPostResponses201ContentApplicationJsonSchema,
    )
    from ._models_py3 import (
        PathsKhpbbuV3InvitationsGetResponses200ContentApplicationJsonSchemaAllof1,
    )
    from ._models_py3 import (
        PathsL3R02CV3DocumentsGetResponses200ContentApplicationJsonSchemaAllof1,
    )
    from ._models_py3 import (
        PathsM3DzbgV3JobDescriptionSearchEmbedPostRequestbodyContentApplicationJsonSchema,
    )
    from ._models_py3 import (
        PathsMnwxgV3DataPointChoicesGetResponses200ContentApplicationJsonSchema,
    )
    from ._models_py3 import (
        PathsO7SnenV3IndexNameDocumentsGetResponses200ContentApplicationJsonSchema,
    )
    from ._models_py3 import PathsOxm5M7V3DocumentsGetResponses200ContentApplicationJsonSchema
    from ._models_py3 import (
        PathsQ5Os5RV3OrganizationMembershipsGetResponses200ContentApplicationJsonSchema,
    )
    from ._models_py3 import (
        PathsVz5Kj2V3ResthookSubscriptionsGetResponses200ContentApplicationJsonSchema,
    )
    from ._models_py3 import PathsWvcyp9V3MappingsGetResponses200ContentApplicationJsonSchemaAllof1
    from ._models_py3 import (
        PathsZ1JuagV3WorkspaceMembershipsGetResponses200ContentApplicationJsonSchema,
    )
    from ._models_py3 import PhoneNumberAnnotation
    from ._models_py3 import PhoneNumberAnnotationParsed
    from ._models_py3 import PydanticModelsResponse
    from ._models_py3 import Rectangle
    from ._models_py3 import RedactConfig
    from ._models_py3 import RegionBias
    from ._models_py3 import RequestError
    from ._models_py3 import RequestErrorErrorsItem
    from ._models_py3 import ResthookSubscription
    from ._models_py3 import ResthookSubscriptionCreate
    from ._models_py3 import ResthookSubscriptionUpdate
    from ._models_py3 import ResthookSubscriptionWorkspace
    from ._models_py3 import Resume
    from ._models_py3 import ResumeData
    from ._models_py3 import ResumeDataName
    from ._models_py3 import ResumeDataPhoneNumberDetailsItem
    from ._models_py3 import ResumeDataRefereesItem
    from ._models_py3 import ResumeDataSectionsItem
    from ._models_py3 import ResumeDataSkillsItem
    from ._models_py3 import ResumeDataSkillsPropertiesItemsItem
    from ._models_py3 import ResumeDataWorkExperienceItem
    from ._models_py3 import ResumeDataWorkExperienceItemDates
    from ._models_py3 import ResumeDataWorkExperienceItemOccupation
    from ._models_py3 import ResumeRedact
    from ._models_py3 import ResumeRedactData
    from ._models_py3 import ResumeSearch
    from ._models_py3 import ResumeSearchConfig
    from ._models_py3 import ResumeSearchConfigSearchToolTheme
    from ._models_py3 import ResumeSearchDetail
    from ._models_py3 import ResumeSearchDetailEducation
    from ._models_py3 import ResumeSearchDetailEducationMissing
    from ._models_py3 import ResumeSearchDetailEducationValueItem
    from ._models_py3 import ResumeSearchDetailExperience
    from ._models_py3 import ResumeSearchDetailJobTitle
    from ._models_py3 import ResumeSearchDetailJobTitleValueItem
    from ._models_py3 import ResumeSearchDetailLanguages
    from ._models_py3 import ResumeSearchDetailLanguagesValueItem
    from ._models_py3 import ResumeSearchDetailLocation
    from ._models_py3 import ResumeSearchDetailLocationValue
    from ._models_py3 import ResumeSearchDetailManagementLevel
    from ._models_py3 import ResumeSearchDetailOccupationGroup
    from ._models_py3 import ResumeSearchDetailSearchExpression
    from ._models_py3 import ResumeSearchDetailSkills
    from ._models_py3 import ResumeSearchDetailSkillsValueItem
    from ._models_py3 import ResumeSearchEmbed
    from ._models_py3 import ResumeSearchMatch
    from ._models_py3 import ResumeSearchMatchDetails
    from ._models_py3 import ResumeSearchParameters
    from ._models_py3 import ResumeSearchParametersCustomData
    from ._models_py3 import ResumeSearchParametersLocation
    from ._models_py3 import ResumeSearchParametersLocationCoordinates
    from ._models_py3 import ResumeSearchParametersSkill
    from ._models_py3 import ResumeSearchResult
    from ._models_py3 import ResumeSkill
    from ._models_py3 import ResumeSkillSourcesItem
    from ._models_py3 import RowAnnotation
    from ._models_py3 import RowAnnotationParsed
    from ._models_py3 import RowBetaAnnotation
    from ._models_py3 import RowBetaAnnotationParsed
    from ._models_py3 import SearchConfigAction
    from ._models_py3 import SearchExpressionSearchScoreComponent
    from ._models_py3 import SearchParametersCustomData
    from ._models_py3 import SkillAnnotation
    from ._models_py3 import SkillAnnotationUpdate
    from ._models_py3 import SkillsSearchScoreComponent
    from ._models_py3 import TableAnnotation
    from ._models_py3 import TableAnnotationParsed
    from ._models_py3 import TableBetaAnnotation
    from ._models_py3 import TableBetaAnnotationParsed
    from ._models_py3 import Tag
    from ._models_py3 import TagCreate
    from ._models_py3 import TagUpdate
    from ._models_py3 import TextAnnotation
    from ._models_py3 import TextAnnotationUpdate
    from ._models_py3 import ThemeConfig
    from ._models_py3 import ThemeConfigPalette
    from ._models_py3 import ThemeConfigPaletteText
    from ._models_py3 import ThemeConfigTypography
    from ._models_py3 import UrlAnnotation
    from ._models_py3 import UrlAnnotationParsed
    from ._models_py3 import UsageByCollection
    from ._models_py3 import UsageByWorkspace
    from ._models_py3 import User
    from ._models_py3 import UserNullable
    from ._models_py3 import ValidationResult
    from ._models_py3 import ValidationResultCreate
    from ._models_py3 import ValidationResultUpdate
    from ._models_py3 import ValidationRule
    from ._models_py3 import ValidationToolConfig
    from ._models_py3 import Workspace
    from ._models_py3 import WorkspaceCollectionsItem
    from ._models_py3 import WorkspaceCollectionsItemExtractor
    from ._models_py3 import WorkspaceCreate
    from ._models_py3 import WorkspaceDocumentSplitter
    from ._models_py3 import WorkspaceMembership
    from ._models_py3 import WorkspaceMembershipCreate
    from ._models_py3 import WorkspaceUpdate
    from ._models_py3 import YearsExperienceAnnotation
    from ._models_py3 import YearsExperienceAnnotationParsed
    from ._models_py3 import YearsExperienceAnnotationUpdate
    from ._models_py3 import YearsExperienceAnnotationUpdateParsed
except (SyntaxError, ImportError):
    from ._models import Accreditation  # type: ignore
    from ._models import Annotation  # type: ignore
    from ._models import AnnotationBase  # type: ignore
    from ._models import AnnotationBatchUpdate  # type: ignore
    from ._models import AnnotationCreate  # type: ignore
    from ._models import AnnotationUpdate  # type: ignore
    from ._models import AnnotationWithValidationResults  # type: ignore
    from ._models import AnotationDelete  # type: ignore
    from ._models import ApiUserCreate  # type: ignore
    from ._models import ApiUserUpdate  # type: ignore
    from ._models import ApiUserWithKey  # type: ignore
    from ._models import ApiUserWithKeyOrganizationsItem  # type: ignore
    from ._models import ApiUserWithoutKey  # type: ignore
    from ._models import ApiUserWithoutKeyOrganizationsItem  # type: ignore
    from ._models import BaseExtractor  # type: ignore
    from ._models import BatchAddTagRequest  # type: ignore
    from ._models import BatchDeleteAnnotationsResponse  # type: ignore
    from ._models import BatchDeleteValidationResultsRequest  # type: ignore
    from ._models import BatchRemoveTagRequest  # type: ignore
    from ._models import ChangedValidationResults  # type: ignore
    from ._models import Collection  # type: ignore
    from ._models import CollectionCreate  # type: ignore
    from ._models import CollectionField  # type: ignore
    from ._models import CollectionUpdate  # type: ignore
    from ._models import CollectionWorkspace  # type: ignore
    from ._models import (
        Components159Ji55SchemasResumesearchdetailPropertiesLanguagesPropertiesValueItemsAllof1,
    )  # type: ignore
    from ._models import (
        Components1Kwk9B6SchemasThemeconfigPropertiesPalettePropertiesBackgroundOneof1,
    )  # type: ignore
    from ._models import (
        Components1TlnsonSchemasJobdescriptionsearchdetailPropertiesLocationPropertiesValueAllof1,
    )  # type: ignore
    from ._models import (
        Components1TryetgSchemasResumedataPropertiesWorkexperienceItemsPropertiesOccupationPropertiesClassification,
    )  # type: ignore
    from ._models import (
        ComponentsH65QjbSchemasResumesearchdetailPropertiesSkillsPropertiesValueItemsAllof1,
    )  # type: ignore
    from ._models import (
        ComponentsN9ShogSchemasResumesearchdetailPropertiesLocationPropertiesValueAllof1,
    )  # type: ignore
    from ._models import ComponentsNqbw24SchemasCustomdatasearchscorecomponentAdditionalproperties  # type: ignore
    from ._models import (
        ComponentsSxu0N3SchemasResumesearchdetailPropertiesEducationPropertiesValueItemsAllof1,
    )  # type: ignore
    from ._models import CurrencyCodeAnnotation  # type: ignore
    from ._models import CustomFieldConfig  # type: ignore
    from ._models import DataField  # type: ignore
    from ._models import DataFieldCreate  # type: ignore
    from ._models import DataFieldCreateDataPoint  # type: ignore
    from ._models import DataFieldCreateField  # type: ignore
    from ._models import DataFieldDataPoint  # type: ignore
    from ._models import DataFieldField  # type: ignore
    from ._models import DataPoint  # type: ignore
    from ._models import DataPointChoice  # type: ignore
    from ._models import DataPointChoiceCreate  # type: ignore
    from ._models import DataPointChoiceForReplace  # type: ignore
    from ._models import DataPointChoiceReplaceRequest  # type: ignore
    from ._models import DataPointChoiceReplaceResponse  # type: ignore
    from ._models import DataPointChoiceReplaceResponseChoicesItem  # type: ignore
    from ._models import DataPointChoiceUpdate  # type: ignore
    from ._models import DataPointCreate  # type: ignore
    from ._models import DataPointUpdate  # type: ignore
    from ._models import DateAnnotation  # type: ignore
    from ._models import DateAnnotationUpdate  # type: ignore
    from ._models import DateRangeAnnotation  # type: ignore
    from ._models import DateRangeAnnotationParsed  # type: ignore
    from ._models import DateRangeValue  # type: ignore
    from ._models import Document  # type: ignore
    from ._models import DocumentCreate  # type: ignore
    from ._models import DocumentEditRequest  # type: ignore
    from ._models import DocumentError  # type: ignore
    from ._models import DocumentMeta  # type: ignore
    from ._models import DocumentMetaChildDocumentsItem  # type: ignore
    from ._models import DocumentMetaCollection  # type: ignore
    from ._models import DocumentMetaCollectionExtractor  # type: ignore
    from ._models import DocumentMetaParentDocument  # type: ignore
    from ._models import DocumentMetaWorkspace  # type: ignore
    from ._models import DocumentSplit  # type: ignore
    from ._models import DocumentSplitPage  # type: ignore
    from ._models import DocumentSplitter  # type: ignore
    from ._models import DocumentType  # type: ignore
    from ._models import DocumentTypeCreate  # type: ignore
    from ._models import DocumentTypeUpdate  # type: ignore
    from ._models import DocumentUpdate  # type: ignore
    from ._models import DocumentWarning  # type: ignore
    from ._models import Education  # type: ignore
    from ._models import EducationDates  # type: ignore
    from ._models import EducationGrade  # type: ignore
    from ._models import EducationSearchScoreComponent  # type: ignore
    from ._models import ExpectedRemunerationAnnotation  # type: ignore
    from ._models import ExpectedRemunerationAnnotationParsed  # type: ignore
    from ._models import ExpectedRemunerationAnnotationUpdate  # type: ignore
    from ._models import ExpectedRemunerationAnnotationUpdateParsed  # type: ignore
    from ._models import ExperienceSearchScoreComponent  # type: ignore
    from ._models import Extractor  # type: ignore
    from ._models import ExtractorBaseExtractor  # type: ignore
    from ._models import ExtractorConfig  # type: ignore
    from ._models import ExtractorCreate  # type: ignore
    from ._models import ExtractorUpdate  # type: ignore
    from ._models import Field  # type: ignore
    from ._models import FieldCategory  # type: ignore
    from ._models import FieldDeprecated  # type: ignore
    from ._models import FieldGroup  # type: ignore
    from ._models import FieldsLayout  # type: ignore
    from ._models import FloatAnnotation  # type: ignore
    from ._models import Get200ApplicationJsonPropertiesItemsItem  # type: ignore
    from ._models import Index  # type: ignore
    from ._models import IndexCreate  # type: ignore
    from ._models import IndexUpdate  # type: ignore
    from ._models import IndexUser  # type: ignore
    from ._models import Invitation  # type: ignore
    from ._models import InvitationCreate  # type: ignore
    from ._models import InvitationRespondedBy  # type: ignore
    from ._models import InvitationResponse  # type: ignore
    from ._models import InvitationUpdate  # type: ignore
    from ._models import Invoice  # type: ignore
    from ._models import InvoiceData  # type: ignore
    from ._models import JobDescription  # type: ignore
    from ._models import JobDescriptionData  # type: ignore
    from ._models import JobDescriptionDataUpdate  # type: ignore
    from ._models import JobDescriptionSearch  # type: ignore
    from ._models import JobDescriptionSearchConfig  # type: ignore
    from ._models import JobDescriptionSearchConfigSearchToolTheme  # type: ignore
    from ._models import JobDescriptionSearchDetail  # type: ignore
    from ._models import JobDescriptionSearchDetailEducation  # type: ignore
    from ._models import JobDescriptionSearchDetailEducationMissing  # type: ignore
    from ._models import JobDescriptionSearchDetailEducationValue  # type: ignore
    from ._models import JobDescriptionSearchDetailExperience  # type: ignore
    from ._models import JobDescriptionSearchDetailJobTitle  # type: ignore
    from ._models import JobDescriptionSearchDetailJobTitleValue  # type: ignore
    from ._models import JobDescriptionSearchDetailLanguages  # type: ignore
    from ._models import JobDescriptionSearchDetailLanguagesValueItem  # type: ignore
    from ._models import JobDescriptionSearchDetailLocation  # type: ignore
    from ._models import JobDescriptionSearchDetailLocationValue  # type: ignore
    from ._models import JobDescriptionSearchDetailManagementLevel  # type: ignore
    from ._models import JobDescriptionSearchDetailOccupationGroup  # type: ignore
    from ._models import JobDescriptionSearchDetailOccupationGroupValue  # type: ignore
    from ._models import JobDescriptionSearchDetailSearchExpression  # type: ignore
    from ._models import JobDescriptionSearchDetailSkills  # type: ignore
    from ._models import JobDescriptionSearchDetailSkillsValueItem  # type: ignore
    from ._models import JobDescriptionSearchEmbed  # type: ignore
    from ._models import JobDescriptionSearchParameters  # type: ignore
    from ._models import JobDescriptionSearchResult  # type: ignore
    from ._models import JobTitleAnnotation  # type: ignore
    from ._models import JobTitleAnnotationParsed  # type: ignore
    from ._models import JobTitleAnnotationParsedClassification  # type: ignore
    from ._models import JobTitleAnnotationUpdate  # type: ignore
    from ._models import JobTitleParsed  # type: ignore
    from ._models import JobTitleParsedClassification  # type: ignore
    from ._models import JobTitleParsedParsed  # type: ignore
    from ._models import JobTitleSearchScoreComponent  # type: ignore
    from ._models import LanguageAnnotation  # type: ignore
    from ._models import LanguageAnnotationUpdate  # type: ignore
    from ._models import LanguagesSearchScoreComponent  # type: ignore
    from ._models import Location  # type: ignore
    from ._models import LocationAnnotation  # type: ignore
    from ._models import LocationAnnotationUpdate  # type: ignore
    from ._models import LocationAnnotationUpdateParsed  # type: ignore
    from ._models import LocationSearchScoreComponent  # type: ignore
    from ._models import ManagementLevelSearchScoreComponent  # type: ignore
    from ._models import Mapping  # type: ignore
    from ._models import MappingCreate  # type: ignore
    from ._models import MappingDataSource  # type: ignore
    from ._models import MappingDataSourceCreate  # type: ignore
    from ._models import MappingUpdate  # type: ignore
    from ._models import Meta  # type: ignore
    from ._models import MetaChildDocumentsItem  # type: ignore
    from ._models import MetaParentDocument  # type: ignore
    from ._models import OccupationGroup  # type: ignore
    from ._models import OccupationGroupSearchResult  # type: ignore
    from ._models import OccupationGroupSearchScoreComponent  # type: ignore
    from ._models import Organization  # type: ignore
    from ._models import OrganizationCreate  # type: ignore
    from ._models import OrganizationMembership  # type: ignore
    from ._models import OrganizationMembershipUpdate  # type: ignore
    from ._models import OrganizationUpdate  # type: ignore
    from ._models import OrganizationValidationToolConfig  # type: ignore
    from ._models import PageMeta  # type: ignore
    from ._models import PaginatedResponse  # type: ignore
    from ._models import PaletteColorOptions  # type: ignore
    from ._models import Paths11PzrpaV3ApiUsersGetResponses200ContentApplicationJsonSchemaAllof1  # type: ignore
    from ._models import (
        Paths11QdcofV3MappingDataSourcesGetResponses200ContentApplicationJsonSchema,
    )  # type: ignore
    from ._models import Paths18Wh2VcV3InvitationsGetResponses200ContentApplicationJsonSchema  # type: ignore
    from ._models import Paths1Czpnk1V3ResumeSearchEmbedPostRequestbodyContentApplicationJsonSchema  # type: ignore
    from ._models import Paths1D5Zg6MV3AnnotationsGetResponses200ContentApplicationJsonSchema  # type: ignore
    from ._models import Paths1Dgz0V9V3AnnotationsGetResponses200ContentApplicationJsonSchemaAllof1  # type: ignore
    from ._models import Paths1Dpvb2PV3MappingsGetResponses200ContentApplicationJsonSchema  # type: ignore
    from ._models import (
        Paths1O6IvdaV3MappingDataSourcesIdentifierValuesGetResponses200ContentApplicationJsonSchemaAllof1,
    )  # type: ignore
    from ._models import (
        Paths1Qojy9V3ResthookSubscriptionsGetResponses200ContentApplicationJsonSchemaAllof1,
    )  # type: ignore
    from ._models import (
        Paths1Qr7BnyV3MappingDataSourcesIdentifierValuesGetResponses200ContentApplicationJsonSchema,
    )  # type: ignore
    from ._models import (
        Paths1UmoszuV3MappingDataSourcesGetResponses200ContentApplicationJsonSchemaAllof1,
    )  # type: ignore
    from ._models import Paths26Civ0V3ApiUsersGetResponses200ContentApplicationJsonSchema  # type: ignore
    from ._models import (
        Paths2Ld2HiV3WorkspaceMembershipsGetResponses200ContentApplicationJsonSchemaAllof1,
    )  # type: ignore
    from ._models import (
        Paths4K6IzqV3DataPointChoicesGetResponses200ContentApplicationJsonSchemaAllof1,
    )  # type: ignore
    from ._models import Paths4T5Cm5V3IndexGetResponses200ContentApplicationJsonSchemaAllof1  # type: ignore
    from ._models import (
        Paths93Fa0ZV3OrganizationMembershipsGetResponses200ContentApplicationJsonSchemaAllof1,
    )  # type: ignore
    from ._models import PathsCl024WV3IndexNameDocumentsPostRequestbodyContentApplicationJsonSchema  # type: ignore
    from ._models import PathsDvrcp3V3IndexGetResponses200ContentApplicationJsonSchema  # type: ignore
    from ._models import (
        PathsFte27NV3IndexNameDocumentsPostResponses201ContentApplicationJsonSchema,
    )  # type: ignore
    from ._models import PathsKhpbbuV3InvitationsGetResponses200ContentApplicationJsonSchemaAllof1  # type: ignore
    from ._models import PathsL3R02CV3DocumentsGetResponses200ContentApplicationJsonSchemaAllof1  # type: ignore
    from ._models import (
        PathsM3DzbgV3JobDescriptionSearchEmbedPostRequestbodyContentApplicationJsonSchema,
    )  # type: ignore
    from ._models import PathsMnwxgV3DataPointChoicesGetResponses200ContentApplicationJsonSchema  # type: ignore
    from ._models import PathsO7SnenV3IndexNameDocumentsGetResponses200ContentApplicationJsonSchema  # type: ignore
    from ._models import PathsOxm5M7V3DocumentsGetResponses200ContentApplicationJsonSchema  # type: ignore
    from ._models import (
        PathsQ5Os5RV3OrganizationMembershipsGetResponses200ContentApplicationJsonSchema,
    )  # type: ignore
    from ._models import (
        PathsVz5Kj2V3ResthookSubscriptionsGetResponses200ContentApplicationJsonSchema,
    )  # type: ignore
    from ._models import PathsWvcyp9V3MappingsGetResponses200ContentApplicationJsonSchemaAllof1  # type: ignore
    from ._models import (
        PathsZ1JuagV3WorkspaceMembershipsGetResponses200ContentApplicationJsonSchema,
    )  # type: ignore
    from ._models import PhoneNumberAnnotation  # type: ignore
    from ._models import PhoneNumberAnnotationParsed  # type: ignore
    from ._models import PydanticModelsResponse  # type: ignore
    from ._models import Rectangle  # type: ignore
    from ._models import RedactConfig  # type: ignore
    from ._models import RegionBias  # type: ignore
    from ._models import RequestError  # type: ignore
    from ._models import RequestErrorErrorsItem  # type: ignore
    from ._models import ResthookSubscription  # type: ignore
    from ._models import ResthookSubscriptionCreate  # type: ignore
    from ._models import ResthookSubscriptionUpdate  # type: ignore
    from ._models import ResthookSubscriptionWorkspace  # type: ignore
    from ._models import Resume  # type: ignore
    from ._models import ResumeData  # type: ignore
    from ._models import ResumeDataName  # type: ignore
    from ._models import ResumeDataPhoneNumberDetailsItem  # type: ignore
    from ._models import ResumeDataRefereesItem  # type: ignore
    from ._models import ResumeDataSectionsItem  # type: ignore
    from ._models import ResumeDataSkillsItem  # type: ignore
    from ._models import ResumeDataSkillsPropertiesItemsItem  # type: ignore
    from ._models import ResumeDataWorkExperienceItem  # type: ignore
    from ._models import ResumeDataWorkExperienceItemDates  # type: ignore
    from ._models import ResumeDataWorkExperienceItemOccupation  # type: ignore
    from ._models import ResumeRedact  # type: ignore
    from ._models import ResumeRedactData  # type: ignore
    from ._models import ResumeSearch  # type: ignore
    from ._models import ResumeSearchConfig  # type: ignore
    from ._models import ResumeSearchConfigSearchToolTheme  # type: ignore
    from ._models import ResumeSearchDetail  # type: ignore
    from ._models import ResumeSearchDetailEducation  # type: ignore
    from ._models import ResumeSearchDetailEducationMissing  # type: ignore
    from ._models import ResumeSearchDetailEducationValueItem  # type: ignore
    from ._models import ResumeSearchDetailExperience  # type: ignore
    from ._models import ResumeSearchDetailJobTitle  # type: ignore
    from ._models import ResumeSearchDetailJobTitleValueItem  # type: ignore
    from ._models import ResumeSearchDetailLanguages  # type: ignore
    from ._models import ResumeSearchDetailLanguagesValueItem  # type: ignore
    from ._models import ResumeSearchDetailLocation  # type: ignore
    from ._models import ResumeSearchDetailLocationValue  # type: ignore
    from ._models import ResumeSearchDetailManagementLevel  # type: ignore
    from ._models import ResumeSearchDetailOccupationGroup  # type: ignore
    from ._models import ResumeSearchDetailSearchExpression  # type: ignore
    from ._models import ResumeSearchDetailSkills  # type: ignore
    from ._models import ResumeSearchDetailSkillsValueItem  # type: ignore
    from ._models import ResumeSearchEmbed  # type: ignore
    from ._models import ResumeSearchMatch  # type: ignore
    from ._models import ResumeSearchMatchDetails  # type: ignore
    from ._models import ResumeSearchParameters  # type: ignore
    from ._models import ResumeSearchParametersCustomData  # type: ignore
    from ._models import ResumeSearchParametersLocation  # type: ignore
    from ._models import ResumeSearchParametersLocationCoordinates  # type: ignore
    from ._models import ResumeSearchParametersSkill  # type: ignore
    from ._models import ResumeSearchResult  # type: ignore
    from ._models import ResumeSkill  # type: ignore
    from ._models import ResumeSkillSourcesItem  # type: ignore
    from ._models import RowAnnotation  # type: ignore
    from ._models import RowAnnotationParsed  # type: ignore
    from ._models import RowBetaAnnotation  # type: ignore
    from ._models import RowBetaAnnotationParsed  # type: ignore
    from ._models import SearchConfigAction  # type: ignore
    from ._models import SearchExpressionSearchScoreComponent  # type: ignore
    from ._models import SearchParametersCustomData  # type: ignore
    from ._models import SkillAnnotation  # type: ignore
    from ._models import SkillAnnotationUpdate  # type: ignore
    from ._models import SkillsSearchScoreComponent  # type: ignore
    from ._models import TableAnnotation  # type: ignore
    from ._models import TableAnnotationParsed  # type: ignore
    from ._models import TableBetaAnnotation  # type: ignore
    from ._models import TableBetaAnnotationParsed  # type: ignore
    from ._models import Tag  # type: ignore
    from ._models import TagCreate  # type: ignore
    from ._models import TagUpdate  # type: ignore
    from ._models import TextAnnotation  # type: ignore
    from ._models import TextAnnotationUpdate  # type: ignore
    from ._models import ThemeConfig  # type: ignore
    from ._models import ThemeConfigPalette  # type: ignore
    from ._models import ThemeConfigPaletteText  # type: ignore
    from ._models import ThemeConfigTypography  # type: ignore
    from ._models import UrlAnnotation  # type: ignore
    from ._models import UrlAnnotationParsed  # type: ignore
    from ._models import UsageByCollection  # type: ignore
    from ._models import UsageByWorkspace  # type: ignore
    from ._models import User  # type: ignore
    from ._models import UserNullable  # type: ignore
    from ._models import ValidationResult  # type: ignore
    from ._models import ValidationResultCreate  # type: ignore
    from ._models import ValidationResultUpdate  # type: ignore
    from ._models import ValidationRule  # type: ignore
    from ._models import ValidationToolConfig  # type: ignore
    from ._models import Workspace  # type: ignore
    from ._models import WorkspaceCollectionsItem  # type: ignore
    from ._models import WorkspaceCollectionsItemExtractor  # type: ignore
    from ._models import WorkspaceCreate  # type: ignore
    from ._models import WorkspaceDocumentSplitter  # type: ignore
    from ._models import WorkspaceMembership  # type: ignore
    from ._models import WorkspaceMembershipCreate  # type: ignore
    from ._models import WorkspaceUpdate  # type: ignore
    from ._models import YearsExperienceAnnotation  # type: ignore
    from ._models import YearsExperienceAnnotationParsed  # type: ignore
    from ._models import YearsExperienceAnnotationUpdate  # type: ignore
    from ._models import YearsExperienceAnnotationUpdateParsed  # type: ignore

from ._affinda_api_enums import (
    AnnotationContentType,
    CollectionDateFormatPreference,
    DateFormatPreference,
    DateRange,
    DocType,
    DocumentFormat,
    DocumentSplitterType,
    DocumentState,
    EducationLevel,
    Enum22,
    IndexDocType,
    InvitationResponseStatus,
    InvitationStatus,
    JobDescriptionSearchConfigDistanceUnit,
    ManagementLevel,
    OrganizationRole,
    OrganizationUserRole,
    Region,
    ResthookEvent,
    ResthookSubscriptionVersion,
    ResumeDataLanguagesItem,
    ResumeSearchConfigDistanceUnit,
    ResumeSkillSourcesItemSection,
    SearchLocationUnit,
    SearchParametersCustomDataFilterType,
    ThemeConfigPaletteMode,
    Version,
    WorkspaceVisibility,
)
from ._patch import __all__ as _patch_all
from ._patch import *  # type: ignore # pylint: disable=unused-wildcard-import
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "Accreditation",
    "Annotation",
    "AnnotationBase",
    "AnnotationBatchUpdate",
    "AnnotationCreate",
    "AnnotationUpdate",
    "AnnotationWithValidationResults",
    "AnotationDelete",
    "ApiUserCreate",
    "ApiUserUpdate",
    "ApiUserWithKey",
    "ApiUserWithKeyOrganizationsItem",
    "ApiUserWithoutKey",
    "ApiUserWithoutKeyOrganizationsItem",
    "BaseExtractor",
    "BatchAddTagRequest",
    "BatchDeleteAnnotationsResponse",
    "BatchDeleteValidationResultsRequest",
    "BatchRemoveTagRequest",
    "ChangedValidationResults",
    "Collection",
    "CollectionCreate",
    "CollectionField",
    "CollectionUpdate",
    "CollectionWorkspace",
    "Components159Ji55SchemasResumesearchdetailPropertiesLanguagesPropertiesValueItemsAllof1",
    "Components1Kwk9B6SchemasThemeconfigPropertiesPalettePropertiesBackgroundOneof1",
    "Components1TlnsonSchemasJobdescriptionsearchdetailPropertiesLocationPropertiesValueAllof1",
    "Components1TryetgSchemasResumedataPropertiesWorkexperienceItemsPropertiesOccupationPropertiesClassification",
    "ComponentsH65QjbSchemasResumesearchdetailPropertiesSkillsPropertiesValueItemsAllof1",
    "ComponentsN9ShogSchemasResumesearchdetailPropertiesLocationPropertiesValueAllof1",
    "ComponentsNqbw24SchemasCustomdatasearchscorecomponentAdditionalproperties",
    "ComponentsSxu0N3SchemasResumesearchdetailPropertiesEducationPropertiesValueItemsAllof1",
    "CurrencyCodeAnnotation",
    "CustomFieldConfig",
    "DataField",
    "DataFieldCreate",
    "DataFieldCreateDataPoint",
    "DataFieldCreateField",
    "DataFieldDataPoint",
    "DataFieldField",
    "DataPoint",
    "DataPointChoice",
    "DataPointChoiceCreate",
    "DataPointChoiceForReplace",
    "DataPointChoiceReplaceRequest",
    "DataPointChoiceReplaceResponse",
    "DataPointChoiceReplaceResponseChoicesItem",
    "DataPointChoiceUpdate",
    "DataPointCreate",
    "DataPointUpdate",
    "DateAnnotation",
    "DateAnnotationUpdate",
    "DateRangeAnnotation",
    "DateRangeAnnotationParsed",
    "DateRangeValue",
    "Document",
    "DocumentCreate",
    "DocumentEditRequest",
    "DocumentError",
    "DocumentMeta",
    "DocumentMetaChildDocumentsItem",
    "DocumentMetaCollection",
    "DocumentMetaCollectionExtractor",
    "DocumentMetaParentDocument",
    "DocumentMetaWorkspace",
    "DocumentSplit",
    "DocumentSplitPage",
    "DocumentSplitter",
    "DocumentType",
    "DocumentTypeCreate",
    "DocumentTypeUpdate",
    "DocumentUpdate",
    "DocumentWarning",
    "Education",
    "EducationDates",
    "EducationGrade",
    "EducationSearchScoreComponent",
    "ExpectedRemunerationAnnotation",
    "ExpectedRemunerationAnnotationParsed",
    "ExpectedRemunerationAnnotationUpdate",
    "ExpectedRemunerationAnnotationUpdateParsed",
    "ExperienceSearchScoreComponent",
    "Extractor",
    "ExtractorBaseExtractor",
    "ExtractorConfig",
    "ExtractorCreate",
    "ExtractorUpdate",
    "Field",
    "FieldCategory",
    "FieldDeprecated",
    "FieldGroup",
    "FieldsLayout",
    "FloatAnnotation",
    "Get200ApplicationJsonPropertiesItemsItem",
    "Index",
    "IndexCreate",
    "IndexUpdate",
    "IndexUser",
    "Invitation",
    "InvitationCreate",
    "InvitationRespondedBy",
    "InvitationResponse",
    "InvitationUpdate",
    "Invoice",
    "InvoiceData",
    "JobDescription",
    "JobDescriptionData",
    "JobDescriptionDataUpdate",
    "JobDescriptionSearch",
    "JobDescriptionSearchConfig",
    "JobDescriptionSearchConfigSearchToolTheme",
    "JobDescriptionSearchDetail",
    "JobDescriptionSearchDetailEducation",
    "JobDescriptionSearchDetailEducationMissing",
    "JobDescriptionSearchDetailEducationValue",
    "JobDescriptionSearchDetailExperience",
    "JobDescriptionSearchDetailJobTitle",
    "JobDescriptionSearchDetailJobTitleValue",
    "JobDescriptionSearchDetailLanguages",
    "JobDescriptionSearchDetailLanguagesValueItem",
    "JobDescriptionSearchDetailLocation",
    "JobDescriptionSearchDetailLocationValue",
    "JobDescriptionSearchDetailManagementLevel",
    "JobDescriptionSearchDetailOccupationGroup",
    "JobDescriptionSearchDetailOccupationGroupValue",
    "JobDescriptionSearchDetailSearchExpression",
    "JobDescriptionSearchDetailSkills",
    "JobDescriptionSearchDetailSkillsValueItem",
    "JobDescriptionSearchEmbed",
    "JobDescriptionSearchParameters",
    "JobDescriptionSearchResult",
    "JobTitleAnnotation",
    "JobTitleAnnotationParsed",
    "JobTitleAnnotationParsedClassification",
    "JobTitleAnnotationUpdate",
    "JobTitleParsed",
    "JobTitleParsedClassification",
    "JobTitleParsedParsed",
    "JobTitleSearchScoreComponent",
    "LanguageAnnotation",
    "LanguageAnnotationUpdate",
    "LanguagesSearchScoreComponent",
    "Location",
    "LocationAnnotation",
    "LocationAnnotationUpdate",
    "LocationAnnotationUpdateParsed",
    "LocationSearchScoreComponent",
    "ManagementLevelSearchScoreComponent",
    "Mapping",
    "MappingCreate",
    "MappingDataSource",
    "MappingDataSourceCreate",
    "MappingUpdate",
    "Meta",
    "MetaChildDocumentsItem",
    "MetaParentDocument",
    "OccupationGroup",
    "OccupationGroupSearchResult",
    "OccupationGroupSearchScoreComponent",
    "Organization",
    "OrganizationCreate",
    "OrganizationMembership",
    "OrganizationMembershipUpdate",
    "OrganizationUpdate",
    "OrganizationValidationToolConfig",
    "PageMeta",
    "PaginatedResponse",
    "PaletteColorOptions",
    "Paths11PzrpaV3ApiUsersGetResponses200ContentApplicationJsonSchemaAllof1",
    "Paths11QdcofV3MappingDataSourcesGetResponses200ContentApplicationJsonSchema",
    "Paths18Wh2VcV3InvitationsGetResponses200ContentApplicationJsonSchema",
    "Paths1Czpnk1V3ResumeSearchEmbedPostRequestbodyContentApplicationJsonSchema",
    "Paths1D5Zg6MV3AnnotationsGetResponses200ContentApplicationJsonSchema",
    "Paths1Dgz0V9V3AnnotationsGetResponses200ContentApplicationJsonSchemaAllof1",
    "Paths1Dpvb2PV3MappingsGetResponses200ContentApplicationJsonSchema",
    "Paths1O6IvdaV3MappingDataSourcesIdentifierValuesGetResponses200ContentApplicationJsonSchemaAllof1",
    "Paths1Qojy9V3ResthookSubscriptionsGetResponses200ContentApplicationJsonSchemaAllof1",
    "Paths1Qr7BnyV3MappingDataSourcesIdentifierValuesGetResponses200ContentApplicationJsonSchema",
    "Paths1UmoszuV3MappingDataSourcesGetResponses200ContentApplicationJsonSchemaAllof1",
    "Paths26Civ0V3ApiUsersGetResponses200ContentApplicationJsonSchema",
    "Paths2Ld2HiV3WorkspaceMembershipsGetResponses200ContentApplicationJsonSchemaAllof1",
    "Paths4K6IzqV3DataPointChoicesGetResponses200ContentApplicationJsonSchemaAllof1",
    "Paths4T5Cm5V3IndexGetResponses200ContentApplicationJsonSchemaAllof1",
    "Paths93Fa0ZV3OrganizationMembershipsGetResponses200ContentApplicationJsonSchemaAllof1",
    "PathsCl024WV3IndexNameDocumentsPostRequestbodyContentApplicationJsonSchema",
    "PathsDvrcp3V3IndexGetResponses200ContentApplicationJsonSchema",
    "PathsFte27NV3IndexNameDocumentsPostResponses201ContentApplicationJsonSchema",
    "PathsKhpbbuV3InvitationsGetResponses200ContentApplicationJsonSchemaAllof1",
    "PathsL3R02CV3DocumentsGetResponses200ContentApplicationJsonSchemaAllof1",
    "PathsM3DzbgV3JobDescriptionSearchEmbedPostRequestbodyContentApplicationJsonSchema",
    "PathsMnwxgV3DataPointChoicesGetResponses200ContentApplicationJsonSchema",
    "PathsO7SnenV3IndexNameDocumentsGetResponses200ContentApplicationJsonSchema",
    "PathsOxm5M7V3DocumentsGetResponses200ContentApplicationJsonSchema",
    "PathsQ5Os5RV3OrganizationMembershipsGetResponses200ContentApplicationJsonSchema",
    "PathsVz5Kj2V3ResthookSubscriptionsGetResponses200ContentApplicationJsonSchema",
    "PathsWvcyp9V3MappingsGetResponses200ContentApplicationJsonSchemaAllof1",
    "PathsZ1JuagV3WorkspaceMembershipsGetResponses200ContentApplicationJsonSchema",
    "PhoneNumberAnnotation",
    "PhoneNumberAnnotationParsed",
    "PydanticModelsResponse",
    "Rectangle",
    "RedactConfig",
    "RegionBias",
    "RequestError",
    "RequestErrorErrorsItem",
    "ResthookSubscription",
    "ResthookSubscriptionCreate",
    "ResthookSubscriptionUpdate",
    "ResthookSubscriptionWorkspace",
    "Resume",
    "ResumeData",
    "ResumeDataName",
    "ResumeDataPhoneNumberDetailsItem",
    "ResumeDataRefereesItem",
    "ResumeDataSectionsItem",
    "ResumeDataSkillsItem",
    "ResumeDataSkillsPropertiesItemsItem",
    "ResumeDataWorkExperienceItem",
    "ResumeDataWorkExperienceItemDates",
    "ResumeDataWorkExperienceItemOccupation",
    "ResumeRedact",
    "ResumeRedactData",
    "ResumeSearch",
    "ResumeSearchConfig",
    "ResumeSearchConfigSearchToolTheme",
    "ResumeSearchDetail",
    "ResumeSearchDetailEducation",
    "ResumeSearchDetailEducationMissing",
    "ResumeSearchDetailEducationValueItem",
    "ResumeSearchDetailExperience",
    "ResumeSearchDetailJobTitle",
    "ResumeSearchDetailJobTitleValueItem",
    "ResumeSearchDetailLanguages",
    "ResumeSearchDetailLanguagesValueItem",
    "ResumeSearchDetailLocation",
    "ResumeSearchDetailLocationValue",
    "ResumeSearchDetailManagementLevel",
    "ResumeSearchDetailOccupationGroup",
    "ResumeSearchDetailSearchExpression",
    "ResumeSearchDetailSkills",
    "ResumeSearchDetailSkillsValueItem",
    "ResumeSearchEmbed",
    "ResumeSearchMatch",
    "ResumeSearchMatchDetails",
    "ResumeSearchParameters",
    "ResumeSearchParametersCustomData",
    "ResumeSearchParametersLocation",
    "ResumeSearchParametersLocationCoordinates",
    "ResumeSearchParametersSkill",
    "ResumeSearchResult",
    "ResumeSkill",
    "ResumeSkillSourcesItem",
    "RowAnnotation",
    "RowAnnotationParsed",
    "RowBetaAnnotation",
    "RowBetaAnnotationParsed",
    "SearchConfigAction",
    "SearchExpressionSearchScoreComponent",
    "SearchParametersCustomData",
    "SkillAnnotation",
    "SkillAnnotationUpdate",
    "SkillsSearchScoreComponent",
    "TableAnnotation",
    "TableAnnotationParsed",
    "TableBetaAnnotation",
    "TableBetaAnnotationParsed",
    "Tag",
    "TagCreate",
    "TagUpdate",
    "TextAnnotation",
    "TextAnnotationUpdate",
    "ThemeConfig",
    "ThemeConfigPalette",
    "ThemeConfigPaletteText",
    "ThemeConfigTypography",
    "UrlAnnotation",
    "UrlAnnotationParsed",
    "UsageByCollection",
    "UsageByWorkspace",
    "User",
    "UserNullable",
    "ValidationResult",
    "ValidationResultCreate",
    "ValidationResultUpdate",
    "ValidationRule",
    "ValidationToolConfig",
    "Workspace",
    "WorkspaceCollectionsItem",
    "WorkspaceCollectionsItemExtractor",
    "WorkspaceCreate",
    "WorkspaceDocumentSplitter",
    "WorkspaceMembership",
    "WorkspaceMembershipCreate",
    "WorkspaceUpdate",
    "YearsExperienceAnnotation",
    "YearsExperienceAnnotationParsed",
    "YearsExperienceAnnotationUpdate",
    "YearsExperienceAnnotationUpdateParsed",
    "AnnotationContentType",
    "CollectionDateFormatPreference",
    "DateFormatPreference",
    "DateRange",
    "DocType",
    "DocumentFormat",
    "DocumentSplitterType",
    "DocumentState",
    "EducationLevel",
    "Enum22",
    "IndexDocType",
    "InvitationResponseStatus",
    "InvitationStatus",
    "JobDescriptionSearchConfigDistanceUnit",
    "ManagementLevel",
    "OrganizationRole",
    "OrganizationUserRole",
    "Region",
    "ResthookEvent",
    "ResthookSubscriptionVersion",
    "ResumeDataLanguagesItem",
    "ResumeSearchConfigDistanceUnit",
    "ResumeSkillSourcesItemSection",
    "SearchLocationUnit",
    "SearchParametersCustomDataFilterType",
    "ThemeConfigPaletteMode",
    "Version",
    "WorkspaceVisibility",
]
__all__.extend([p for p in _patch_all if p not in __all__])
_patch_sdk()
